Skip to main content

SpatialBench Data Generator CLI

See the main README.md for full documentation.

Installation

Install Using Python

Install this tool with Python:

pip install spatialbench-cli

Install Using Rust

Install Rust and this tool:

curl --proto '=https' --tlsv1.2 -sSf https://sh.rustup.rs | sh
cargo install spatialbench-cli

CLI Usage

We tried to make the spatialbench-cli experience as close to dbgen as possible for no other reason than maybe make it easier for you to have a drop-in replacement.

$ spatialbench-cli -h
TPC-H Data Generator

Usage: spatialbench-cli [OPTIONS]

Options:
  -s, --scale-factor <SCALE_FACTOR>
          Scale factor to address (default: 1) [default: 1]
  -o, --output-dir <OUTPUT_DIR>
          Output directory for generated files (default: current directory) [default: .]
  -T, --tables <TABLES>
          Which tables to generate (default: all) [possible values: vehicle, driver, customer, trip, building, zone]
  -p, --parts <PARTS>
          Number of parts to generate (manual parallel generation) [default: 1]
      --part <PART>
          Which part to generate (1-based, only relevant if parts > 1) [default: 1]
  -f, --format <FORMAT>
          Output format: parquet, tbl, csv (default: parquet) [default: parquet] [possible values: parquet, tbl, csv]
  -n, --num-threads <NUM_THREADS>
          The number of threads for parallel generation, defaults to the number of CPUs [default: 8]
  -c, --parquet-compression <PARQUET_COMPRESSION>
          Parquet block compression format. Default is SNAPPY [default: SNAPPY]
  -v, --verbose
          Verbose output (default: false)
      --stdout
          Write the output to stdout instead of a file
  -h, --help
          Print help (see more with '--help')

For example generating a dataset with a scale factor of 1 (1GB) can be done like this:

$ spatialbench-cli -s 1 --output-dir=/tmp/spatialbench

Release files for spatialbench-cli 0.2.0

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for spatialbench-cli 0.2.0
File Size Uploaded
spatialbench_cli-0.2.0.tar.gz 2.3 MB Details

Built distributions (wheels)

Table of built distributions (wheels) for spatialbench-cli 0.2.0
File
spatialbench_cli-0.2.0-py3-none-win_amd64.whl Python 3 none Windows x86-64 Details
spatialbench_cli-0.2.0-py3-none-win32.whl Python 3 none Windows x86-32 Details
spatialbench_cli-0.2.0-py3-none-musllinux_1_2_x86_64.whl Python 3 none Linux musl 1.2+ x86-64 Details
spatialbench_cli-0.2.0-py3-none-musllinux_1_2_i686.whl Python 3 none Linux musl 1.2+ x86-32 Details
spatialbench_cli-0.2.0-py3-none-musllinux_1_2_armv7l.whl Python 3 none Linux musl 1.2+ ARMv7l Details
spatialbench_cli-0.2.0-py3-none-musllinux_1_2_aarch64.whl Python 3 none Linux musl 1.2+ ARM64 Details
spatialbench_cli-0.2.0-py3-none-manylinux_2_17_x86_64.manylinux2014_x86_64.whl Python 3 none Linux glibc 2.17+ x86-64 Details
spatialbench_cli-0.2.0-py3-none-manylinux_2_17_ppc64le.manylinux2014_ppc64le.whl Python 3 none Linux glibc 2.17+ PowerPC 64-le Details
spatialbench_cli-0.2.0-py3-none-manylinux_2_17_i686.manylinux2014_i686.whl Python 3 none Linux glibc 2.17+ x86-32 Details
spatialbench_cli-0.2.0-py3-none-manylinux_2_17_armv7l.manylinux2014_armv7l.whl Python 3 none Linux glibc 2.17+ ARMv7l Details
spatialbench_cli-0.2.0-py3-none-manylinux_2_17_aarch64.manylinux2014_aarch64.whl Python 3 none Linux glibc 2.17+ ARM64 Details
spatialbench_cli-0.2.0-py3-none-macosx_11_0_arm64.whl Python 3 none macOS 11.0+ ARM64 Details
spatialbench_cli-0.2.0-py3-none-macosx_10_12_x86_64.whl Python 3 none macOS 10.12+ x86-64 Details

Total release size: 528.1 MB

Release files / spatialbench_cli-0.2.0.tar.gz

Download URL spatialbench_cli-0.2.0.tar.gz
Size 2.3 MB
Tags Source
SHA-256 checksum
How to use checksums
98d9e4e0da783286f4b9a86c5f304b9230e8054b0ed5b507e7c9942009e20982
BLAKE2b-256 checksum
How to use checksums
f0f8fb5742cc793621b29faf928efc95b158243907049c352604ee0e4f95b675
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via maturin/1.12.4

Release files / spatialbench_cli-0.2.0-py3-none-win_amd64.whl

Download URL spatialbench_cli-0.2.0-py3-none-win_amd64.whl
Size 36.5 MB
Tags Python 3 Windows x86-64
SHA-256 checksum
How to use checksums
ef438bd16e47ef4524dc875ee389b4f47031f4e282eaeb01dc6304654ae1b462
BLAKE2b-256 checksum
How to use checksums
05628f5d4c3ae4407fa6798d5670abb05fd77855bdb52870b838fcc661624110
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via maturin/1.12.4

Release files / spatialbench_cli-0.2.0-py3-none-win32.whl

Download URL spatialbench_cli-0.2.0-py3-none-win32.whl
Size 32.3 MB
Tags Python 3 Windows x86-32
SHA-256 checksum
How to use checksums
7c3d8d9c3ed52a9f1dadfadf68d62c08a23cc239696968b6d95cf43a24e93dbc
BLAKE2b-256 checksum
How to use checksums
e1d6166cd16c3473271f0005564e020940185192b917652822c5a5448a35fbe9
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via maturin/1.12.4

Release files / spatialbench_cli-0.2.0-py3-none-musllinux_1_2_x86_64.whl

Download URL spatialbench_cli-0.2.0-py3-none-musllinux_1_2_x86_64.whl
Size 41.6 MB
Tags Linux musl 1.2+ x86-64 Python 3
SHA-256 checksum
How to use checksums
341b762490a5f68cc3e173a0e17d4387b88aa45aad8c738e60dd6525de2b90a1
BLAKE2b-256 checksum
How to use checksums
591a29ee50ec3944d0937af695172a760d6971c61837b9fbddc170f68f1a5d0e
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via maturin/1.12.4

Release files / spatialbench_cli-0.2.0-py3-none-musllinux_1_2_i686.whl

Download URL spatialbench_cli-0.2.0-py3-none-musllinux_1_2_i686.whl
Size 43.4 MB
Tags Linux musl 1.2+ x86-32 Python 3
SHA-256 checksum
How to use checksums
daa97191181e9f87207f9fb2df09c89526c3c173311a2c53a774630e1c73418b
BLAKE2b-256 checksum
How to use checksums
ff092ab3d69c70b513621ea26e80b62c7feef0f6786202d52f1cf9902571d5d0
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via maturin/1.12.4

Release files / spatialbench_cli-0.2.0-py3-none-musllinux_1_2_armv7l.whl

Download URL spatialbench_cli-0.2.0-py3-none-musllinux_1_2_armv7l.whl
Size 41.0 MB
Tags Linux musl 1.2+ ARMv7l Python 3
SHA-256 checksum
How to use checksums
2acc8cf9a34b3857186c943aacb3993f87f3ce806e351df19b9f63532efb20b1
BLAKE2b-256 checksum
How to use checksums
c55ed5aa3a7b8b58be5f37c7c8adad4ffe6c11afd6de54d5a431ca70fe0892e3
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via maturin/1.12.4

Release files / spatialbench_cli-0.2.0-py3-none-musllinux_1_2_aarch64.whl

Download URL spatialbench_cli-0.2.0-py3-none-musllinux_1_2_aarch64.whl
Size 39.8 MB
Tags Linux musl 1.2+ ARM64 Python 3
SHA-256 checksum
How to use checksums
594eae1f0312b47ddd15b19191d964b5387c253c094d2929b0a4cd5326bad35d
BLAKE2b-256 checksum
How to use checksums
a8004115ffb8fb2866d4db40155038a7138a9b1b6570cb500040a8841a58024f
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via maturin/1.12.4

Release files / spatialbench_cli-0.2.0-py3-none-manylinux_2_17_x86_64.manylinux2014_x86_64.whl

Download URL spatialbench_cli-0.2.0-py3-none-manylinux_2_17_x86_64.manylinux2014_x86_64.whl
Size 41.2 MB
Tags Linux glibc 2.17+ x86-64 Python 3
SHA-256 checksum
How to use checksums
3c06088e1fa1fe9b8e4baf9acd9a88dcb52bde932b5c4aec2ae2b6061699dd2e
BLAKE2b-256 checksum
How to use checksums
4213e21f10543673f9ece07603825cd8c4bba62ac6df9a95226c6513e16f7853
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via maturin/1.12.4

Release files / spatialbench_cli-0.2.0-py3-none-manylinux_2_17_ppc64le.manylinux2014_ppc64le.whl

Download URL spatialbench_cli-0.2.0-py3-none-manylinux_2_17_ppc64le.manylinux2014_ppc64le.whl
Size 46.1 MB
Tags Linux glibc 2.17+ PowerPC 64-le Python 3
SHA-256 checksum
How to use checksums
7b3d8cb8d159326b50b1760606619a1d064c8f1a8536ce9b76fb8e1d749bc375
BLAKE2b-256 checksum
How to use checksums
f9325eae6333a4f48b4562ce564f3921e4275793d102fa2655dd733f68d46616
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via maturin/1.12.4

Release files / spatialbench_cli-0.2.0-py3-none-manylinux_2_17_i686.manylinux2014_i686.whl

Download URL spatialbench_cli-0.2.0-py3-none-manylinux_2_17_i686.manylinux2014_i686.whl
Size 46.1 MB
Tags Linux glibc 2.17+ x86-32 Python 3
SHA-256 checksum
How to use checksums
92e97240ab06e2b745678e0f9ad24112b531f6c45badad708e955bf0dc5a898a
BLAKE2b-256 checksum
How to use checksums
0d5d8bde68e35f3ea59cb75dd8f1ddd8dec02e71bea2180b6ac4fb46d2beb705
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via maturin/1.12.4

Release files / spatialbench_cli-0.2.0-py3-none-manylinux_2_17_armv7l.manylinux2014_armv7l.whl

Download URL spatialbench_cli-0.2.0-py3-none-manylinux_2_17_armv7l.manylinux2014_armv7l.whl
Size 41.1 MB
Tags Linux glibc 2.17+ ARMv7l Python 3
SHA-256 checksum
How to use checksums
3750069f6eec8a68c4e3d0059ca65c5a91cf0f1db96a7ed56f683c8058ef8741
BLAKE2b-256 checksum
How to use checksums
3eea40c34b799fa8156b2256720166828b0335a02471da66d5fd9d3f65ab8cb6
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via maturin/1.12.4

Release files / spatialbench_cli-0.2.0-py3-none-manylinux_2_17_aarch64.manylinux2014_aarch64.whl

Download URL spatialbench_cli-0.2.0-py3-none-manylinux_2_17_aarch64.manylinux2014_aarch64.whl
Size 40.3 MB
Tags Linux glibc 2.17+ ARM64 Python 3
SHA-256 checksum
How to use checksums
d1cb910b335b8e6ad26fc70ea2e1719b67d2cc41d550f8482833520a3d6e4772
BLAKE2b-256 checksum
How to use checksums
a9df3ed54e2d2c4d42b8daec8094e3449adb4b515fd3ba3370b936097d35ae41
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via maturin/1.12.4

Release files / spatialbench_cli-0.2.0-py3-none-macosx_11_0_arm64.whl

Download URL spatialbench_cli-0.2.0-py3-none-macosx_11_0_arm64.whl
Size 37.1 MB
Tags Python 3 macOS 11.0+ ARM64
SHA-256 checksum
How to use checksums
49566c20f3906ecedb4ab0bffafaa6d45d14c8f4f3007598030f35b94a29d797
BLAKE2b-256 checksum
How to use checksums
0c0f3409aa400d30f541e1cf9ef4d7b5f5651b81ad865df94e9506f50e53b0e7
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via maturin/1.12.4

Release files / spatialbench_cli-0.2.0-py3-none-macosx_10_12_x86_64.whl

Download URL spatialbench_cli-0.2.0-py3-none-macosx_10_12_x86_64.whl
Size 39.2 MB
Tags Python 3 macOS 10.12+ x86-64
SHA-256 checksum
How to use checksums
2e1453cbf80e785033127fba37c099ea74bcade2e8462ecf724b5ad4a4322544
BLAKE2b-256 checksum
How to use checksums
78b0e585b7478e7d0857f9b64aa88b9fbd806f3fff032d22d0cdf741d7da1ee9
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via maturin/1.12.4

Release history Release notifications | RSS feed

This release

0.2.0 This release

14 release files

0.1.0

14 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page